==> test-support-1.3-sources.jar: com/xebialabs/deployit/test/support/utils/VelocityUtils.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.test.support.utils;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.StringWriter;

import org.apache.velocity.VelocityContext;
import org.apache.velocity.app.VelocityEngine;
import org.springframework.core.io.ClassPathResource;

public class VelocityUtils {

	public static String evaluateTemplate(VelocityContext context, String templateResourcePath) {
		VelocityEngine engine = new VelocityEngine();
		try {
			engine.init();
		} catch (Exception exc) {
			throw new RuntimeException("Cannot initialize Velocity", exc);
		}

		ClassPathResource templateResource = new ClassPathResource(templateResourcePath);
		InputStream dsTemplateIn;
		try {
			dsTemplateIn = templateResource.getInputStream();
		} catch (IOException exc) {
			throw new RuntimeException("Cannot open template file " + templateResourcePath, exc);
		}

		StringWriter evaluatedTemplateWriter = new StringWriter();
		try {
			engine.evaluate(context, evaluatedTemplateWriter, templateResourcePath, new InputStreamReader(dsTemplateIn));
		} catch (Exception exc) {
			throw new RuntimeException("Cannot evaluate template " + templateResourcePath, exc);
		}
		return evaluatedTemplateWriter.toString();
	}

}

==> test-support-1.4.1-sources.jar: com/xebialabs/deployit/test/support/utils/VelocityUtils.java <==
/*
 * Copyright (c) 2008-2011 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.test.support.utils;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.StringWriter;

import org.apache.velocity.VelocityContext;
import org.apache.velocity.app.VelocityEngine;
import org.apache.velocity.runtime.RuntimeConstants;
import org.apache.velocity.runtime.log.CommonsLogLogChute;
import org.springframework.core.io.ClassPathResource;

public class VelocityUtils {

	public static String evaluateTemplate(VelocityContext context, String templateResourcePath) {
		VelocityEngine engine = new VelocityEngine();
		// workaround a log4j incompatibility between Deployit 3.0 and Velocity < 2.0
		engine.addProperty(RuntimeConstants.RUNTIME_LOG_LOGSYSTEM_CLASS, CommonsLogLogChute.class.getName());
		try {
			engine.init();
		} catch (Exception exc) {
			throw new RuntimeException("Cannot initialize Velocity", exc);
		}

		ClassPathResource templateResource = new ClassPathResource(templateResourcePath);
		InputStream dsTemplateIn;
		try {
			dsTemplateIn = templateResource.getInputStream();
		} catch (IOException exc) {
			throw new RuntimeException("Cannot open template file " + templateResourcePath, exc);
		}

		StringWriter evaluatedTemplateWriter = new StringWriter();
		try {
			engine.evaluate(context, evaluatedTemplateWriter, templateResourcePath, new InputStreamReader(dsTemplateIn));
		} catch (Exception exc) {
			throw new RuntimeException("Cannot evaluate template " + templateResourcePath, exc);
		}
		return evaluatedTemplateWriter.toString();
	}

}
